@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,23 +11,21 @@
 #
 ##############################################################################
 """Image object
-
-$Id: Image.py 108041 2010-01-12 00:26:43Z optilude $
 """
+
 from cgi import escape
 from cStringIO import StringIO
 from mimetools import choose_boundary
 import struct
 
+from AccessControl.class_init import InitializeClass
 from AccessControl.Permissions import change_images_and_files
 from AccessControl.Permissions import view_management_screens
 from AccessControl.Permissions import view as View
 from AccessControl.Permissions import ftp_access
 from AccessControl.Permissions import delete_objects
-from AccessControl.Role import RoleManager
 from AccessControl.SecurityInfo import ClassSecurityInfo
 from Acquisition import Implicit
-from App.class_init import InitializeClass
 from App.special_dtml import DTMLFile
 from DateTime.DateTime import DateTime
 from Persistence import Persistent
@@ -36,7 +34,6 @@ from webdav.interfaces import IWriteLock
 from webdav.Lockable import ResourceLockedError
 from ZPublisher import HTTPRangeSupport
 from ZPublisher.HTTPRequest import FileUpload
-from ZPublisher.Iterators import filestream_iterator
 from zExceptions import Redirect
 from zope.contenttype import guess_content_type
 from zope.interface import implementedBy
@@ -44,6 +41,7 @@ from zope.interface import implements
 
 from OFS.Cache import Cacheable
 from OFS.PropertyManager import PropertyManager
+from OFS.role import RoleManager
 from OFS.SimpleItem import Item_w__name__
 
 from zope.event import notify
@@ -67,23 +65,23 @@ def manage_addFile(self, id, file='', title='', precondition='',
     precondition = str(precondition)
 
     id, title = cookId(id, title, file)
-    
+
     self=self.this()
 
     # First, we create the file without data:
     self._setObject(id, File(id,title,'',content_type, precondition))
-    
+
     newFile = self._getOb(id)
-    
+
     # Now we "upload" the data.  By doing this in two steps, we
     # can use a database trick to make the upload more efficient.
     if file:
         newFile.manage_upload(file)
     if content_type:
         newFile.content_type=content_type
-    
+
     notify(ObjectCreatedEvent(newFile))
-    
+
     if REQUEST is not None:
         REQUEST['RESPONSE'].redirect(self.absolute_url()+'/manage_main')
 
@@ -120,10 +118,8 @@ class File(Persistent, Implicit, PropertyManager,
 
     manage_options=(
         (
-        {'label':'Edit', 'action':'manage_main',
-         'help':('OFSP','File_Edit.stx')},
-        {'label':'View', 'action':'',
-         'help':('OFSP','File_View.stx')},
+        {'label': 'Edit', 'action': 'manage_main'},
+        {'label': 'View', 'action': ''},
         )
         + PropertyManager.manage_options
         + RoleManager.manage_options
@@ -440,8 +436,7 @@ class File(Persistent, Implicit, PropertyManager,
 
     security.declareProtected(View, 'PrincipiaSearchSource')
     def PrincipiaSearchSource(self):
-        """ Allow file objects to be searched.
-        """
+        # Allow file objects to be searched.
         if self.content_type.startswith('text/'):
             return str(self.data)
         return ''
@@ -477,9 +472,9 @@ class File(Persistent, Implicit, PropertyManager,
             self.update_data(filedata, content_type, len(filedata))
         else:
             self.ZCacheable_invalidate()
-        
+
         notify(ObjectModifiedEvent(self))
-        
+
         if REQUEST:
             message="Saved changes."
             return self.manage_main(self,REQUEST,manage_tabs_message=message)
@@ -498,16 +493,16 @@ class File(Persistent, Implicit, PropertyManager,
         content_type=self._get_content_type(file, data, self.__name__,
                                             'application/octet-stream')
         self.update_data(data, content_type, size)
-        
+
         notify(ObjectModifiedEvent(self))
-        
+
         if REQUEST:
             message="Saved changes."
             return self.manage_main(self,REQUEST,manage_tabs_message=message)
 
     def _get_content_type(self, file, body, id, content_type=None):
         headers=getattr(file, 'headers', None)
-        if headers and headers.has_key('content-type'):
+        if headers and 'content-type' in headers:
             content_type=headers['content-type']
         else:
             if not isinstance(body, str): body=body.data
@@ -604,10 +599,8 @@ class File(Persistent, Implicit, PropertyManager,
 
     security.declareProtected(View, 'get_size')
     def get_size(self):
-        """Get the size of a file or image.
-
-        Returns the size of the file or image.
-        """
+        # Get the size of a file or image.
+        # Returns the size of the file or image.
         size=self.size
         if size is None: size=len(self.data)
         return size
@@ -617,10 +610,8 @@ class File(Persistent, Implicit, PropertyManager,
 
     security.declareProtected(View, 'getContentType')
     def getContentType(self):
-        """Get the content type of a file or image.
-
-        Returns the content type (MIME type) of a file or image.
-        """
+        # Get the content type of a file or image.
+        # Returns the content type (MIME type) of a file or image.
         return self.content_type
 
 
@@ -657,6 +648,9 @@ class File(Persistent, Implicit, PropertyManager,
 
         return ''
 
+InitializeClass(File)
+
+
 manage_addImageForm=DTMLFile('dtml/imageAdd',globals(),
                              Kind='Image',kind='image')
 def manage_addImage(self, id, file, title='', precondition='', content_type='',
@@ -678,18 +672,18 @@ def manage_addImage(self, id, file, title='', precondition='', content_type='',
 
     # First, we create the image without data:
     self._setObject(id, Image(id,title,'',content_type, precondition))
-    
+
     newFile = self._getOb(id)
-    
+
     # Now we "upload" the data.  By doing this in two steps, we
     # can use a database trick to make the upload more efficient.
     if file:
         newFile.manage_upload(file)
     if content_type:
         newFile.content_type=content_type
-    
+
     notify(ObjectCreatedEvent(newFile))
-    
+
     if REQUEST is not None:
         try:    url=self.DestinationURL()
         except: url=REQUEST['URL1']
@@ -788,10 +782,8 @@ class Image(File):
                  )
 
     manage_options=(
-        ({'label':'Edit', 'action':'manage_main',
-         'help':('OFSP','Image_Edit.stx')},
-         {'label':'View', 'action':'view_image_or_file',
-         'help':('OFSP','Image_View.stx')},)
+        ({'label':'Edit', 'action':'manage_main'},
+         {'label':'View', 'action':'view_image_or_file'}, )
         + PropertyManager.manage_options
         + RoleManager.manage_options
         + Item_w__name__.manage_options
@@ -815,7 +807,7 @@ class Image(File):
         if isinstance(data, unicode):
             raise TypeError('Data can only be str or file-like.  '
                             'Unicode objects are expressly forbidden.')
-        
+
         if size is None: size=len(data)
 
         self.size=size
@@ -841,21 +833,20 @@ class Image(File):
     security.declareProtected(View, 'tag')
     def tag(self, height=None, width=None, alt=None,
             scale=0, xscale=0, yscale=0, css_class=None, title=None, **args):
-        """
-        Generate an HTML IMG tag for this image, with customization.
-        Arguments to self.tag() can be any valid attributes of an IMG tag.
-        'src' will always be an absolute pathname, to prevent redundant
-        downloading of images. Defaults are applied intelligently for
-        'height', 'width', and 'alt'. If specified, the 'scale', 'xscale',
-        and 'yscale' keyword arguments will be used to automatically adjust
-        the output height and width values of the image tag.
+        #Generate an HTML IMG tag for this image, with customization.
+        #Arguments to self.tag() can be any valid attributes of an IMG tag.
+        #'src' will always be an absolute pathname, to prevent redundant
+        #downloading of images. Defaults are applied intelligently for
+        #'height', 'width', and 'alt'. If specified, the 'scale', 'xscale',
+        #and 'yscale' keyword arguments will be used to automatically adjust
+        #the output height and width values of the image tag.
+
+        #Since 'class' is a Python reserved word, it cannot be passed in
+        #directly in keyword arguments which is a problem if you are
+        #trying to use 'tag()' to include a CSS class. The tag() method
+        #will accept a 'css_class' argument that will be converted to
+        #'class' in the output tag to work around this.
 
-        Since 'class' is a Python reserved word, it cannot be passed in
-        directly in keyword arguments which is a problem if you are
-        trying to use 'tag()' to include a CSS class. The tag() method
-        will accept a 'css_class' argument that will be converted to
-        'class' in the output tag to work around this.
-        """
         if height is None: height=self.height
         if width is None:  width=self.width
 
@@ -898,6 +889,8 @@ class Image(File):
 
         return '%s />' % result
 
+InitializeClass(Image)
+
 
 def cookId(id, title, file):
     if not id and hasattr(file,'filename'):
