@@ -1,35 +1,37 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
-# FOR A PARTICULAR PURPOSE
+# FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
 """Initialize the Zope2 Package and provide a published module
 """
 
 from zope.component import queryMultiAdapter
+from zope.event import notify
+from zope.processlifetime import DatabaseOpened
+from zope.processlifetime import DatabaseOpenedWithRoot
+
 from AccessControl.SecurityManagement import newSecurityManager
 from AccessControl.SecurityManagement import noSecurityManager
 from Acquisition import aq_acquire
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Acquisition import aq_parent
+from Acquisition.interfaces import IAcquirer
 from App.config import getConfiguration
 from time import asctime
-from types import StringType, ListType
-from zExceptions import upgradeException
 from zExceptions import Redirect
 from zExceptions import Unauthorized
 from ZODB.POSException import ConflictError
 import transaction
 import AccessControl.User
-import App.FindHomes
 import ExtensionClass
 import imp
 import logging
@@ -40,17 +42,26 @@ import App.ZApplication
 import Zope2
 import ZPublisher
 
-from zope.event import notify
-from zope.processlifetime import DatabaseOpened
-
 app = None
 startup_time = asctime()
 
 
+def load_zcml():
+    # This hook is overriden by ZopeTestCase
+    from .zcml import load_site
+    load_site()
+
+    # Set up Zope2 specific vocabulary registry
+    from .schema import configure_vocabulary_registry
+    configure_vocabulary_registry()
+
+
 def startup():
     from App.PersistentExtra import patchPersistent
     import Globals  # to set / fetch data
     patchPersistent()
+    from Zope2.App import patches
+    patches.apply_patches()
 
     global app
 
@@ -67,7 +78,7 @@ def startup():
             m=imp.find_module('custom_zodb',[configuration.testinghome])
         except:
             m=imp.find_module('custom_zodb',[configuration.instancehome])
-    except:
+    except Exception:
         # if there is no custom_zodb, use the config file specified databases
         DB = dbtab.getDatabase('/', is_root=1)
     else:
@@ -92,7 +103,7 @@ def startup():
         from ZODB.ActivityMonitor import ActivityMonitor
         DB.setActivityMonitor(ActivityMonitor())
 
-    Globals.DB = DB # Ick, this is temporary until we come up with some registry
+    Globals.DB = DB
     Zope2.DB = DB
 
     # Hook for providing multiple transaction object manager undo support:
@@ -105,6 +116,9 @@ def startup():
     # "Log on" as system user
     newSecurityManager(None, AccessControl.User.system)
 
+    # Set up the CA
+    load_zcml()
+
     # Set up the "app" object that automagically opens
     # connections
     app = App.ZApplication.ZApplicationWrapper(
@@ -127,6 +141,8 @@ def startup():
     global startup_time
     startup_time = asctime()
 
+    notify(DatabaseOpenedWithRoot(DB))
+
     Zope2.zpublisher_transactions_manager = TransactionsManager()
     Zope2.zpublisher_exception_hook = zpublisher_exception_hook
     Zope2.zpublisher_validated_hook = validated_hook
@@ -138,7 +154,10 @@ def validated_hook(request, user):
 
 
 class RequestContainer(ExtensionClass.Base):
-    def __init__(self,r): self.REQUEST=r
+
+    def __init__(self, r):
+        self.REQUEST=r
+
 
 class ZPublisherExceptionHook:
 
@@ -168,8 +187,6 @@ class ZPublisherExceptionHook:
 
     def __call__(self, published, REQUEST, t, v, traceback):
         try:
-            t, v = upgradeException(t, v)
-
             if t is SystemExit or issubclass(t, Redirect):
                 raise t, v, traceback
 
@@ -196,7 +213,7 @@ class ZPublisherExceptionHook:
             else:
                 error_log_url = log.raising((t, v, traceback))
 
-            if (REQUEST is None or 
+            if (REQUEST is None or
                 (getattr(REQUEST.get('RESPONSE', None), '_error_format', '')
                  != 'text/html')):
                 raise t, v, traceback
@@ -205,17 +222,27 @@ class ZPublisherExceptionHook:
             # raise the rendered value as the exception value
             # (basically the same that 'raise_standardErrorMessage'
             # does. The view is named 'index.html' because that's what
-            # Zope 3 uses as well.
+            # zope.publisher uses as well.
             view = queryMultiAdapter((v, REQUEST), name=u'index.html')
             if view is not None:
+                if IAcquirer.providedBy(view) and IAcquirer.providedBy(published):
+                    view = view.__of__(published)
+                else:
+                    view.__parent__ = published
                 v = view()
+                if issubclass(t, Unauthorized):
+                    # Re-raise Unauthorized to make sure it is handled
+                    # correctly. We can't do that with all exceptions
+                    # because some don't work with the rendered v as
+                    # argument.
+                    raise t, v, traceback
                 response = REQUEST.RESPONSE
                 response.setStatus(t)
                 response.setBody(v)
                 return response
 
             if (published is None or published is app or
-                type(published) is ListType):
+                isinstance(published, list)):
                 # At least get the top-level object
                 published=app.__bobo_traverse__(REQUEST).__of__(
                     RequestContainer(REQUEST))
@@ -243,20 +270,20 @@ class ZPublisherExceptionHook:
             if REQUEST.get('AUTHENTICATED_USER', None) is None:
                 REQUEST['AUTHENTICATED_USER'] = AccessControl.User.nobody
 
-            try:
-                result = f(client, REQUEST, t, v, 
-                           traceback, 
-                           error_log_url=error_log_url)
-                if result is not None:
-                    t, v, traceback = result
-                    response = REQUEST.RESPONSE
-                    response.setStatus(t)
-                    response.setBody(v)
-                    return response
-            except TypeError:
-                # Pre 2.6 call signature
-                f(client, REQUEST, t, v, traceback)
-
+            result = f(client, REQUEST, t, v, traceback,
+                       error_log_url=error_log_url)
+            if result is not None:
+                t, v, traceback = result
+                if issubclass(t, Unauthorized):
+                    # Re-raise Unauthorized to make sure it is handled
+                    # correctly. We can't do that with all exceptions
+                    # because some don't work with the rendered v as
+                    # argument.
+                    raise t, v, traceback
+                response = REQUEST.RESPONSE
+                response.setStatus(t)
+                response.setBody(v)
+                return response
         finally:
             traceback = None
 
@@ -298,7 +325,7 @@ class TransactionsManager:
 
             while object is not None and \
                   not hasattr(object, 'getPhysicalPath'):
-                if not hasattr(object, '__name__'):
+                if getattr(object, '__name__', None) is None:
                     object = None
                     break
                 to_append = (object.__name__,) + to_append
